aboutsummaryrefslogtreecommitdiffstats
path: root/cmake/jsoncpp.cmake
diff options
context:
space:
mode:
Diffstat (limited to 'cmake/jsoncpp.cmake')
-rw-r--r--cmake/jsoncpp.cmake4
1 files changed, 2 insertions, 2 deletions
diff --git a/cmake/jsoncpp.cmake b/cmake/jsoncpp.cmake
index ea3218ef..318a526e 100644
--- a/cmake/jsoncpp.cmake
+++ b/cmake/jsoncpp.cmake
@@ -15,9 +15,9 @@ set(JSONCPP_INCLUDE_DIR "${prefix}/include")
# versions used in the CI runs.
if(EMSCRIPTEN)
# Do not include all flags in CMAKE_CXX_FLAGS for emscripten,
# but only use -std=c++11. Using all flags causes build failures
# at the moment.
- set(JSONCPP_CXX_FLAGS -std=c++11)
+ set(JSONCPP_CXX_FLAGS -std=c++14)
else()
set(JSONCPP_CXX_FLAGS ${CMAKE_CXX_FLAGS})
endif()
@@ -15,9 +15,9 @@ set(JSONCPP_INCLUDE_DIR "${prefix}/include")
if(EMSCRIPTEN)
# Do not include all flags in CMAKE_CXX_FLAGS for emscripten,
- # but only use -std=c++11. Using all flags causes build failures
+ # but only use -std=c++14. Using all flags causes build failures
# at the moment.